@@ -1,5 +1,8 @@
-from dagster import DagsterInstance, MetadataEntry
-from dagster import _check as check
+from dagster import (
+    DagsterInstance,
+    MetadataEntry,
+    _check as check,
+)
 from dagster._core.definitions.reconstruct import ReconstructablePipeline
 from dagster._core.events import EngineEventData
 from dagster._core.execution.api import create_execution_plan, execute_plan_iterator
